﻿//-----------------------------------------------------------------------
//  RescueLevel.cs 
//  Created by Bennie Lewis 
//  University of Central Florida 
//  Intelligent Agents Lab
//  Description: Creates the Simulated level and setup the environment.
//  Name:            Date:                  Update/Change/Fix:
//  Bennie Lewis     02/03/2009             Created file
//  Bennie Lewis     03/14/2009             Updated Rescue Level 
//-----------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Robotics.Simulation;
using Microsoft.Robotics.Simulation.Engine;
using Microsoft.Robotics.Simulation.Physics;
using Microsoft.Robotics.PhysicalModel;


namespace RSARSim
{
    class RescueLevel
    {
        public RescueLevel()
        {
        }
        public void AddSky()
        {
            // Add a sky using a static texture. We will use the sky texture
            // to do per pixel lighting on each simulation visual entity
            SkyEntity sky = new SkyEntity("sky.dds", "sky_diff.dds");
            SimulationEngine.GlobalInstancePort.Insert(sky);

            // Add a directional light to simulate the sun.
            /*LightSourceEntity sun = new LightSourceEntity();
            sun.State.Name = "Sun";
            sun.Type = LightSourceEntityType.Directional;
            sun.Color = new Vector4(0.8f, 0.8f, 0.8f, 1);
            sun.Direction = new Vector3(-1.0f, -1.0f, 0.5f);
            SimulationEngine.GlobalInstancePort.Insert(sun);*/
        }

        public void AddGround()
        {
            HeightFieldShapeProperties hf = new HeightFieldShapeProperties("height field",
                64, // number of rows 
                100, // distance in meters, between rows
                64, // number of columns
                100, // distance in meters, between columns
                1, // scale factor to multiple height values 
                -1000); // vertical extent of the height field. Should be set to large negative values

            // create array with height samples
            hf.HeightSamples = new HeightFieldSample[hf.RowCount * hf.ColumnCount];
            for (int i = 0; i < hf.RowCount * hf.ColumnCount; i++)
            {
                hf.HeightSamples[i] = new HeightFieldSample();
                hf.HeightSamples[i].Height = (short)(Math.Sin(i * 0.01));
            }

            // create a material for the entire field. We could also specify material per sample.
            hf.Material = new MaterialProperties("ground", 0.8f, 0.5f, 0.8f);

            // insert ground entity in simulation and specify a texture
            SimulationEngine.GlobalInstancePort.Insert(new HeightFieldEntity(hf, "concrete_Mayang_b.dds"));
        }

        public void AddbrickLevel()
        {
            // Builds the walls for the Level
            //---- left wall 1 brick box Yellowzone wall----
            BoxShapeProperties tBoxShape = null;
            SingleShapeEntity tBoxEntity = null;

            tBoxShape = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 10.0f));
            tBoxShape.Material = new MaterialProperties("tbox", 0.5f, 0.3f, 0.5f);
            tBoxEntity = new SingleShapeEntity(new BoxShape(tBoxShape), new Vector3(-9.0f, 1.2f, -5.0f));
            tBoxEntity.State.Assets.DefaultTexture = "yellowzone.bmp";
            tBoxEntity.State.Name = "texbox";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity);

            //---- left wall 2 brick box Redzone wall----
            BoxShapeProperties tBoxShape2 = null;
            SingleShapeEntity tBoxEntity2 = null;

            tBoxShape2 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 20.0f));
            tBoxShape2.Material = new MaterialProperties("tbox2", 0.5f, 0.3f, 0.5f);
            tBoxEntity2 = new SingleShapeEntity(new BoxShape(tBoxShape2), new Vector3(-9.0f, 1.2f, -20.0f));
            tBoxEntity2.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity2.State.Name = "texbox2";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity2);

            //---- back wall 1 brick box ----
            BoxShapeProperties tBoxShape3 = null;
            SingleShapeEntity tBoxEntity3 = null;

            tBoxShape3 = new BoxShapeProperties(10000f, new Pose(), new Vector3(40.0f, 2.5f, 0.2f));
            tBoxShape3.Material = new MaterialProperties("tbox3", 0.5f, 0.3f, 0.5f);
            tBoxEntity3 = new SingleShapeEntity(new BoxShape(tBoxShape3), new Vector3(10.92f, 1.2f, -30.098f));
            tBoxEntity3.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity3.State.Name = "texbox3";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity3);

            //---- right wall 1 brick box ----
            BoxShapeProperties tBoxShape4 = null;
            SingleShapeEntity tBoxEntity4 = null;

            tBoxShape4 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 30.0f));
            tBoxShape4.Material = new MaterialProperties("tbox4", 0.5f, 0.3f, 0.5f);
            tBoxEntity4 = new SingleShapeEntity(new BoxShape(tBoxShape4), new Vector3(30.8f, 1.2f, -14.98f));
            tBoxEntity4.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity4.State.Name = "texbox4";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity4);

            //---- entrance wall brick box ----
            BoxShapeProperties tBoxShape5 = null;
            SingleShapeEntity tBoxEntity5 = null;

            tBoxShape5 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 6.0f));
            tBoxShape5.Material = new MaterialProperties("tbox5", 0.5f, 0.3f, 0.5f);
            tBoxEntity5 = new SingleShapeEntity(new BoxShape(tBoxShape5), new Vector3(-6.0f, 1.2f, -3.0f));
            tBoxEntity5.State.Assets.DefaultTexture = "bluezone.bmp";
            tBoxEntity5.State.Name = "texbox5";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity5);

            //---- front wall brick box ----
            BoxShapeProperties tBoxShape6 = null;
            SingleShapeEntity tBoxEntity6 = null;

            tBoxShape6 = new BoxShapeProperties(10000f, new Pose(), new Vector3(36.59f, 2.5f, 0.2f));
            tBoxShape6.Material = new MaterialProperties("tbox6", 0.5f, 0.3f, 0.5f);
            tBoxEntity6 = new SingleShapeEntity(new BoxShape(tBoxShape6), new Vector3(12.4f, 1.2f, -0.1f));
            tBoxEntity6.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity6.State.Name = "texbox6";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity6);

            //---- Hallway wall 1 brick box ----
            BoxShapeProperties tBoxShape7 = null;
            SingleShapeEntity tBoxEntity7 = null;

            tBoxShape7 = new BoxShapeProperties(10000f, new Pose(), new Vector3(6.0f, 2.5f, 0.2f));
            tBoxShape7.Material = new MaterialProperties("tbox7", 0.5f, 0.3f, 0.5f);
            tBoxEntity7 = new SingleShapeEntity(new BoxShape(tBoxShape7), new Vector3(-5.85f, 1.2f, -10.0f));
            tBoxEntity7.State.Assets.DefaultTexture = "bluezone.bmp";
            tBoxEntity7.State.Name = "texbox7";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity7);

            //---- room 1 wall brick box ----
            BoxShapeProperties tBoxShape8 = null;
            SingleShapeEntity tBoxEntity8 = null;

            tBoxShape8 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 4.8f));
            tBoxShape8.Material = new MaterialProperties("tbox8", 0.5f, 0.3f, 0.5f);
            tBoxEntity8 = new SingleShapeEntity(new BoxShape(tBoxShape8), new Vector3(-1.0f, 1.2f, -3.6f));
            tBoxEntity8.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity8.State.Name = "texbox8";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity8);

            //---- room 2 wall brick box ----
            BoxShapeProperties tBoxShape9 = null;
            SingleShapeEntity tBoxEntity9 = null;

            tBoxShape9 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 5.78f));
            tBoxShape9.Material = new MaterialProperties("tbox9", 0.5f, 0.3f, 0.5f);
            tBoxEntity9 = new SingleShapeEntity(new BoxShape(tBoxShape9), new Vector3(5.0f, 1.2f, -3.098f));
            tBoxEntity9.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity9.State.Name = "texbox9";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity9);

            //---- Hallway wall 2 wall brick box ----
            BoxShapeProperties tBoxShape10 = null;
            SingleShapeEntity tBoxEntity10 = null;

            tBoxShape10 = new BoxShapeProperties(10000f, new Pose(), new Vector3(10.0f, 2.5f, 0.2f));
            tBoxShape10.Material = new MaterialProperties("tbox10", 0.5f, 0.3f, 0.5f);
            tBoxEntity10 = new SingleShapeEntity(new BoxShape(tBoxShape10), new Vector3(7.0f, 1.2f, -10.0f));
            tBoxEntity10.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity10.State.Name = "texbox10";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity10);

            //---- room 1 back wall brick box ----
            BoxShapeProperties tBoxShape11 = null;
            SingleShapeEntity tBoxEntity11 = null;

            tBoxShape11 = new BoxShapeProperties(10000f, new Pose(), new Vector3(8.0f, 2.5f, 0.2f));
            tBoxShape11.Material = new MaterialProperties("tbox11", 0.5f, 0.3f, 0.5f);
            tBoxEntity11 = new SingleShapeEntity(new BoxShape(tBoxShape11), new Vector3(-2.06f, 1.2f, -6.12f));
            tBoxEntity11.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity11.State.Name = "texbox11";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity11);

            //---- room 3 side wall brick box ----
            BoxShapeProperties tBoxShape12 = null;
            SingleShapeEntity tBoxEntity12 = null;

            tBoxShape12 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 5.78f));
            tBoxShape12.Material = new MaterialProperties("tbox12", 0.5f, 0.3f, 0.5f);
            tBoxEntity12 = new SingleShapeEntity(new BoxShape(tBoxShape12), new Vector3(12.0f, 1.2f, -3.098f));
            tBoxEntity12.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity12.State.Name = "texbox12";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity12);

            //---- room 4 side wall brick box ----
            BoxShapeProperties tBoxShape13 = null;
            SingleShapeEntity tBoxEntity13 = null;

            tBoxShape13 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 5.78f));
            tBoxShape13.Material = new MaterialProperties("tbox13", 0.5f, 0.3f, 0.5f);
            tBoxEntity13 = new SingleShapeEntity(new BoxShape(tBoxShape13), new Vector3(19.0f, 1.2f, -3.098f));
            tBoxEntity13.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity13.State.Name = "texbox13";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity13);

            //---- back room wall 1 brick box ----
            BoxShapeProperties tBoxShape14 = null;
            SingleShapeEntity tBoxEntity14 = null;

            tBoxShape14 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 5.78f));
            tBoxShape14.Material = new MaterialProperties("tbox14", 0.5f, 0.3f, 0.5f);
            tBoxEntity14 = new SingleShapeEntity(new BoxShape(tBoxShape14), new Vector3(24.0f, 1.2f, -3.098f));
            tBoxEntity14.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity14.State.Name = "texbox14";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity14);

            //---- room 2 back wall brick box ----
            BoxShapeProperties tBoxShape15 = null;
            SingleShapeEntity tBoxEntity15 = null;

            tBoxShape15 = new BoxShapeProperties(10000f, new Pose(), new Vector3(8.0f, 2.5f, 0.2f));
            tBoxShape15.Material = new MaterialProperties("tbox15", 0.5f, 0.3f, 0.5f);
            tBoxEntity15 = new SingleShapeEntity(new BoxShape(tBoxShape15), new Vector3(12.0f, 1.2f, -6.12f));
            tBoxEntity15.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity15.State.Name = "texbox15";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity15);

            //---- leftside room 1 wall brick box ----
            BoxShapeProperties tBoxShape16 = null;
            SingleShapeEntity tBoxEntity16 = null;

            tBoxShape16 = new BoxShapeProperties(10000f, new Pose(), new Vector3(6.0f, 2.5f, 0.2f));
            tBoxShape16.Material = new MaterialProperties("tbox16", 0.5f, 0.3f, 0.5f);
            tBoxEntity16 = new SingleShapeEntity(new BoxShape(tBoxShape16), new Vector3(-5.85f, 1.2f, -15.0f));
            tBoxEntity16.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity16.State.Name = "texbox16";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity16);

            //---- leftside room 2 back wall brick box ----
            BoxShapeProperties tBoxShape17 = null;
            SingleShapeEntity tBoxEntity17 = null;

            tBoxShape17 = new BoxShapeProperties(10000f, new Pose(), new Vector3(6.0f, 2.5f, 0.2f));
            tBoxShape17.Material = new MaterialProperties("tbox17", 0.5f, 0.3f, 0.5f);
            tBoxEntity17 = new SingleShapeEntity(new BoxShape(tBoxShape17), new Vector3(-5.85f, 1.2f, -20.0f));
            tBoxEntity17.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity17.State.Name = "texbox17";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity17);

            //---- leftside room 3 wall brick box ----
            BoxShapeProperties tBoxShape18 = null;
            SingleShapeEntity tBoxEntity18 = null;

            tBoxShape18 = new BoxShapeProperties(10000f, new Pose(), new Vector3(6.0f, 2.5f, 0.2f));
            tBoxShape18.Material = new MaterialProperties("tbox18", 0.5f, 0.3f, 0.5f);
            tBoxEntity18 = new SingleShapeEntity(new BoxShape(tBoxShape18), new Vector3(-5.85f, 1.2f, -25.0f));
            tBoxEntity18.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity18.State.Name = "texbox18";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity18);

            //---- leftside room 1 front wall brick box ----
            BoxShapeProperties tBoxShape19 = null;
            SingleShapeEntity tBoxEntity19 = null;

            tBoxShape19 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 6.0f));
            tBoxShape19.Material = new MaterialProperties("tbox19", 0.5f, 0.3f, 0.5f);
            tBoxEntity19 = new SingleShapeEntity(new BoxShape(tBoxShape19), new Vector3(-2.73f, 1.2f, -15.0f));
            tBoxEntity19.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity19.State.Name = "texbox19";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity19);

            //---- leftside room 3 front wall brick box ----
            BoxShapeProperties tBoxShape20 = null;
            SingleShapeEntity tBoxEntity20 = null;

            tBoxShape20 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 6.0f));
            tBoxShape20.Material = new MaterialProperties("tbox20", 0.5f, 0.3f, 0.5f);
            tBoxEntity20 = new SingleShapeEntity(new BoxShape(tBoxShape20), new Vector3(-2.73f, 1.2f, -25.0f));
            tBoxEntity20.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity20.State.Name = "texbox20";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity20);

            //---- SideHallway 1 wall brick box ----
            BoxShapeProperties tBoxShape21 = null;
            SingleShapeEntity tBoxEntity21 = null;

            tBoxShape21 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 5.78f));
            tBoxShape21.Material = new MaterialProperties("tbox21", 0.5f, 0.3f, 0.5f);
            tBoxEntity21 = new SingleShapeEntity(new BoxShape(tBoxShape21), new Vector3(1.9f, 1.2f, -12.78f));
            tBoxEntity21.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity21.State.Name = "texbox21";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity21);

            //---- SideHallway 2 wall brick box ----
            BoxShapeProperties tBoxShape22 = null;
            SingleShapeEntity tBoxEntity22 = null;

            tBoxShape22 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 5.78f));
            tBoxShape22.Material = new MaterialProperties("tbox22", 0.5f, 0.3f, 0.5f);
            tBoxEntity22 = new SingleShapeEntity(new BoxShape(tBoxShape22), new Vector3(1.9f, 1.2f, -22.0f));
            tBoxEntity22.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity22.State.Name = "texbox22";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity22);

            //---- right SideHallway 1 wall brick box ----
            BoxShapeProperties tBoxShape23 = null;
            SingleShapeEntity tBoxEntity23 = null;

            tBoxShape23 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 5.78f));
            tBoxShape23.Material = new MaterialProperties("tbox23", 0.5f, 0.3f, 0.5f);
            tBoxEntity23 = new SingleShapeEntity(new BoxShape(tBoxShape23), new Vector3(12.1f, 1.2f, -12.78f));
            tBoxEntity23.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity23.State.Name = "texbox23";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity23);

            //---- right SideHallway 2 wall brick box ----
            BoxShapeProperties tBoxShape24 = null;
            SingleShapeEntity tBoxEntity24 = null;

            tBoxShape24 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 5.78f));
            tBoxShape24.Material = new MaterialProperties("tbox24", 0.5f, 0.3f, 0.5f);
            tBoxEntity24 = new SingleShapeEntity(new BoxShape(tBoxShape24), new Vector3(12.1f, 1.2f, -22.0f));
            tBoxEntity24.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity24.State.Name = "texbox24";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity24);

            //---- Back Hallway wall 1 back wall brick box ----
            BoxShapeProperties tBoxShape25 = null;
            SingleShapeEntity tBoxEntity25 = null;

            tBoxShape25 = new BoxShapeProperties(10000f, new Pose(), new Vector3(10.0f, 2.5f, 0.2f));
            tBoxShape25.Material = new MaterialProperties("tbox25", 0.5f, 0.3f, 0.5f);
            tBoxEntity25 = new SingleShapeEntity(new BoxShape(tBoxShape25), new Vector3(7.0f, 1.2f, -24.8f));
            tBoxEntity25.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity25.State.Name = "texbox25";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity25);

            //---- right SideHallway 2 wall brick box ----
            BoxShapeProperties tBoxShape26 = null;
            SingleShapeEntity tBoxEntity26 = null;

            tBoxShape26 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 15.0f));
            tBoxShape26.Material = new MaterialProperties("tbox26", 0.5f, 0.3f, 0.5f);
            tBoxEntity26 = new SingleShapeEntity(new BoxShape(tBoxShape26), new Vector3(17.0f, 1.2f, -17.5f));
            tBoxEntity26.State.Assets.DefaultTexture = "bluezone.bmp";
            tBoxEntity26.State.Name = "texbox26";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity26);

            //---- Hallway wall 3 wall brick box ----
            BoxShapeProperties tBoxShape27 = null;
            SingleShapeEntity tBoxEntity27 = null;

            tBoxShape27 = new BoxShapeProperties(10000f, new Pose(), new Vector3(8.0f, 2.5f, 0.2f));
            tBoxShape27.Material = new MaterialProperties("tbox27", 0.5f, 0.3f, 0.5f);
            tBoxEntity27 = new SingleShapeEntity(new BoxShape(tBoxShape27), new Vector3(21.12f, 1.2f, -10.13f));
            tBoxEntity27.State.Assets.DefaultTexture = "bluezone.bmp";
            tBoxEntity27.State.Name = "texbox27";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity27);

            //---- room 4 back wall brick box ----
            BoxShapeProperties tBoxShape28 = null;
            SingleShapeEntity tBoxEntity28 = null;

            tBoxShape28 = new BoxShapeProperties(10000f, new Pose(), new Vector3(6.0f, 2.5f, 0.2f));
            tBoxShape28.Material = new MaterialProperties("tbox28", 0.5f, 0.3f, 0.5f);
            tBoxEntity28 = new SingleShapeEntity(new BoxShape(tBoxShape28), new Vector3(25.0f, 1.2f, -6.12f));
            tBoxEntity28.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity28.State.Name = "texbox28";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity28);

            //---- right room 1 wall brick box ----
            BoxShapeProperties tBoxShape29 = null;
            SingleShapeEntity tBoxEntity29 = null;

            tBoxShape29 = new BoxShapeProperties(10000f, new Pose(), new Vector3(6.0f, 2.5f, 0.2f));
            tBoxShape29.Material = new MaterialProperties("tbox29", 0.5f, 0.3f, 0.5f);
            tBoxEntity29 = new SingleShapeEntity(new BoxShape(tBoxShape29), new Vector3(20.12f, 1.2f, -14.0f));
            tBoxEntity29.State.Assets.DefaultTexture = "yellowzone.bmp";
            tBoxEntity29.State.Name = "texbox29";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity29);

            //---- right room 2 wall brick box ----
            BoxShapeProperties tBoxShape30 = null;
            SingleShapeEntity tBoxEntity30 = null;

            tBoxShape30 = new BoxShapeProperties(10000f, new Pose(), new Vector3(6.0f, 2.5f, 0.2f));
            tBoxShape30.Material = new MaterialProperties("tbox30", 0.5f, 0.3f, 0.5f);
            tBoxEntity30 = new SingleShapeEntity(new BoxShape(tBoxShape30), new Vector3(20.12f, 1.2f, -20.0f));
            tBoxEntity30.State.Assets.DefaultTexture = "yellowzone.bmp";
            tBoxEntity30.State.Name = "texbox30";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity30);

            //---- right SideHallway 3 wall brick box ----
            BoxShapeProperties tBoxShape31 = null;
            SingleShapeEntity tBoxEntity31 = null;

            tBoxShape31 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 15.0f));
            tBoxShape31.Material = new MaterialProperties("tbox31", 0.5f, 0.3f, 0.5f);
            tBoxEntity31 = new SingleShapeEntity(new BoxShape(tBoxShape31), new Vector3(27.2f, 1.2f, -17.5f));
            tBoxEntity31.State.Assets.DefaultTexture = "bluezone.bmp";
            tBoxEntity31.State.Name = "texbox31";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity31);

            //---- Back Hallway wall 3 wall brick box ----
            BoxShapeProperties tBoxShape32 = null;
            SingleShapeEntity tBoxEntity32 = null;

            tBoxShape32 = new BoxShapeProperties(10000f, new Pose(), new Vector3(8.0f, 2.5f, 0.2f));
            tBoxShape32.Material = new MaterialProperties("tbox32", 0.5f, 0.3f, 0.5f);
            tBoxEntity32 = new SingleShapeEntity(new BoxShape(tBoxShape32), new Vector3(23.1f, 1.2f, -24.9f));
            tBoxEntity32.State.Assets.DefaultTexture = "bluezone.bmp";
            tBoxEntity32.State.Name = "texbox32";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity32);

            //---- right room 2 mid wall brick box ----
            BoxShapeProperties tBoxShape33 = null;
            SingleShapeEntity tBoxEntity33 = null;

            tBoxShape33 = new BoxShapeProperties(10000f, new Pose(), new Vector3(4.0f, 2.5f, 0.2f));
            tBoxShape33.Material = new MaterialProperties("tbox33", 0.5f, 0.3f, 0.5f);
            tBoxEntity33 = new SingleShapeEntity(new BoxShape(tBoxShape33), new Vector3(25.1f, 1.2f, -17.0f));
            tBoxEntity33.State.Assets.DefaultTexture = "yellowzone.bmp";
            tBoxEntity33.State.Name = "texbox33";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity33);

            //---- right room 1 front wall brick box ----
            BoxShapeProperties tBoxShape34 = null;
            SingleShapeEntity tBoxEntity34 = null;

            tBoxShape34 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 2.0f));
            tBoxShape34.Material = new MaterialProperties("tbox34", 0.5f, 0.3f, 0.5f);
            tBoxEntity34 = new SingleShapeEntity(new BoxShape(tBoxShape34), new Vector3(23.23f, 1.2f, -13.1f));
            tBoxEntity34.State.Assets.DefaultTexture = "yellowzone.bmp";
            tBoxEntity34.State.Name = "texbox34";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity34);

            //---- Back room 1 front wall 1 back wall brick box ----
            BoxShapeProperties tBoxShape35 = null;
            SingleShapeEntity tBoxEntity35 = null;

            tBoxShape35 = new BoxShapeProperties(10000f, new Pose(), new Vector3(6.0f, 2.5f, 0.2f));
            tBoxShape35.Material = new MaterialProperties("tbox35", 0.5f, 0.3f, 0.5f);
            tBoxEntity35 = new SingleShapeEntity(new BoxShape(tBoxShape35), new Vector3(7.0f, 1.2f, -19.0f));
            tBoxEntity35.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity35.State.Name = "texbox35";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity35);

            //---- Back front room 1 front wall 1 back wall brick box ----
            BoxShapeProperties tBoxShape36 = null;
            SingleShapeEntity tBoxEntity36 = null;

            tBoxShape36 = new BoxShapeProperties(10000f, new Pose(), new Vector3(6.0f, 2.5f, 0.2f));
            tBoxShape36.Material = new MaterialProperties("tbox36", 0.5f, 0.3f, 0.5f);
            tBoxEntity36 = new SingleShapeEntity(new BoxShape(tBoxShape36), new Vector3(7.0f, 1.2f, -15.5f));
            tBoxEntity36.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity36.State.Name = "texbox36";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity36);

            //---- Back front room 1 split wall 1 back wall brick box ----
            BoxShapeProperties tBoxShape37 = null;
            SingleShapeEntity tBoxEntity37 = null;

            tBoxShape37 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 2.0f));
            tBoxShape37.Material = new MaterialProperties("tbox37", 0.5f, 0.3f, 0.5f);
            tBoxEntity37 = new SingleShapeEntity(new BoxShape(tBoxShape37), new Vector3(7.0f, 1.2f, -14.18f));
            tBoxEntity37.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity37.State.Name = "texbox37";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity37);

            //---- Back room 1 split wall 1 back wall brick box ----
            BoxShapeProperties tBoxShape38 = null;
            SingleShapeEntity tBoxEntity38 = null;

            tBoxShape38 = new BoxShapeProperties(10000f, new Pose(), new Vector3(0.2f, 2.5f, 2.0f));
            tBoxShape38.Material = new MaterialProperties("tbox38", 0.5f, 0.3f, 0.5f);
            tBoxEntity38 = new SingleShapeEntity(new BoxShape(tBoxShape38), new Vector3(7.0f, 1.2f, -20.12f));
            tBoxEntity38.State.Assets.DefaultTexture = "redzone.bmp";
            tBoxEntity38.State.Name = "texbox38";
            SimulationEngine.GlobalInstancePort.Insert(tBoxEntity38);

        }

        public void Addvictims()
        {
            SingleShapeEntity Victim1 = new SingleShapeEntity(
                new BoxShape(
                    new BoxShapeProperties(
                    100.0f, // mass in kilograms.
                    new Pose(new Vector3(0.0f, 0.0f, 0.18f)), // relative pose
                    new Vector3(0.45f, 1.2f, 0.30f))), // dimensions
                    new Vector3(-3.0f, 0.0f, -2.0f));  // Position
            Victim1.State.Assets.Mesh = "Victims/Victim1.obj";
            Victim1.State.Assets.DefaultTexture = "Victim1.bmp";
            Victim1.State.Name = "Victim1";
            //Victim1.RotationAngles = new Vector3(4.0f, 0.0f, 4.0f);
            SimulationEngine.GlobalInstancePort.Insert(Victim1);
            

            SingleShapeEntity Victim2 = new SingleShapeEntity(
                new BoxShape(
                    new BoxShapeProperties(
                    100.0f, // mass in kilograms.
                    new Pose(new Vector3(0.0f, 0.0f, 0.18f)), // relative pose
                    new Vector3(0.45f, 1.2f, 0.30f))), // dimensions
                    new Vector3(-5.0f, 0.0f, -24.0f));  // Position
            Victim2.State.Assets.Mesh = "Victims/Victim2.obj";
            Victim2.State.Assets.DefaultTexture = "Victim2.bmp";
            Victim2.State.Name = "Victim2";
            SimulationEngine.GlobalInstancePort.Insert(Victim2);

            SingleShapeEntity Victim3 = new SingleShapeEntity(
                new BoxShape(
                    new BoxShapeProperties(
                    100.0f, // mass in kilograms.
                    new Pose(new Vector3(0.0f, 0.0f, 0.18f)), // relative pose
                    new Vector3(0.45f, 1.2f, 0.30f))), // dimensions
                    new Vector3(11.0f, 0.0f, -5.0f));  // Position
            Victim3.State.Assets.Mesh = "Victims/Victim3.obj";
            Victim3.State.Assets.DefaultTexture = "Victim3.bmp";
            Victim3.State.Name = "Victim3";
            SimulationEngine.GlobalInstancePort.Insert(Victim3);

            SingleShapeEntity Victim4 = new SingleShapeEntity(
                new BoxShape(
                    new BoxShapeProperties(
                    100.0f, // mass in kilograms.
                    new Pose(new Vector3(0.0f, 0.0f, 0.18f)), // relative pose
                    new Vector3(0.45f, 1.2f, 0.30f))), // dimensions
                    new Vector3(22.0f, 0.0f, -13.0f));  // Position
            Victim4.State.Assets.Mesh = "Victims/Victim4.obj";
            Victim4.State.Assets.DefaultTexture = "Victim4.bmp";
            Victim4.State.Name = "Victim4";
            SimulationEngine.GlobalInstancePort.Insert(Victim4);

            SingleShapeEntity Victim5 = new SingleShapeEntity(
                new BoxShape(
                    new BoxShapeProperties(
                    100.0f, // mass in kilograms.
                    new Pose(new Vector3(0.0f, 0.0f, 0.18f)), // relative pose
                    new Vector3(0.45f, 1.2f, 0.30f))), // dimensions
                    new Vector3(8.0f, 0.0f, -21.0f));  // Position
            Victim5.State.Assets.Mesh = "Victims/Victim5.obj";
            Victim5.State.Assets.DefaultTexture = "Victim5.bmp";
            Victim5.State.Name = "Victim5";
            SimulationEngine.GlobalInstancePort.Insert(Victim5);

            SingleShapeEntity Victim6 = new SingleShapeEntity(
                new BoxShape(
                    new BoxShapeProperties(
                    100.0f, // mass in kilograms.
                    new Pose(new Vector3(0.0f, 0.0f, 0.18f)), // relative pose
                    new Vector3(0.45f, 1.2f, 0.30f))), // dimensions
                    new Vector3(25.0f, 0.0f, -5.0f));  // Position
            Victim6.State.Assets.Mesh = "Victims/Victim6.obj";
            Victim6.State.Assets.DefaultTexture = "Victim6.bmp";
            Victim6.State.Name = "Victim6";
            SimulationEngine.GlobalInstancePort.Insert(Victim6);

            SingleShapeEntity Victim7 = new SingleShapeEntity(
                new BoxShape(
                    new BoxShapeProperties(
                    100.0f, // mass in kilograms.
                    new Pose(new Vector3(0.0f, 0.0f, 0.18f)), // relative pose
                    new Vector3(0.45f, 1.2f, 0.30f))), // dimensions
                    new Vector3(6.0f, 0.0f, -15.0f));  // Position
            Victim7.State.Assets.Mesh = "Victims/Victim7.obj";
            Victim7.State.Assets.DefaultTexture = "Victim7.bmp";
            Victim7.State.Name = "Victim7";
            SimulationEngine.GlobalInstancePort.Insert(Victim7);

            SingleShapeEntity Victim8 = new SingleShapeEntity(
                new BoxShape(
                    new BoxShapeProperties(
                    100.0f, // mass in kilograms.
                    new Pose(new Vector3(0.0f, 0.0f, 0.18f)), // relative pose
                    new Vector3(0.45f, 1.2f, 0.30f))), // dimensions
                    new Vector3(26.0f, 0.0f, -24.0f));  // Position
            Victim8.State.Assets.Mesh = "Victims/Victim8.obj";
            Victim8.State.Assets.DefaultTexture = "Victim8.bmp";
            Victim8.State.Name = "Victim8";
            SimulationEngine.GlobalInstancePort.Insert(Victim8);

            SingleShapeEntity Victim9 = new SingleShapeEntity(
                new BoxShape(
                    new BoxShapeProperties(
                    100.0f, // mass in kilograms.
                    new Pose(new Vector3(0.0f, 0.0f, 0.18f)), // relative pose
                    new Vector3(0.45f, 1.2f, 0.30f))), // dimensions
                    new Vector3(-7.0f, 0.0f, -14.0f));  // Position
            Victim9.State.Assets.Mesh = "Victims/Victim9.obj";
            Victim9.State.Assets.DefaultTexture = "Victim9.bmp";
            Victim9.State.Name = "Victim9";
            SimulationEngine.GlobalInstancePort.Insert(Victim9);

            SingleShapeEntity Victim10 = new SingleShapeEntity(
                new BoxShape(
                    new BoxShapeProperties(
                    100.0f, // mass in kilograms.
                    new Pose(new Vector3(0.0f, 0.0f, 0.18f)), // relative pose
                    new Vector3(0.45f, 1.2f, 0.30f))), // dimensions
                    new Vector3(-8.0f, 0.0f, -28.0f));  // Position
            Victim10.State.Assets.Mesh = "Victims/Victim10.obj";
            Victim10.State.Assets.DefaultTexture = "Victim10.bmp";
            Victim10.State.Name = "Victim10";
            SimulationEngine.GlobalInstancePort.Insert(Victim10);

        }
    }
}
